#!/bin/sh

# setting the identifications of the page code (depend of OS)
# TODO: read from TBarCodeLib/encoding.cpp
osname=`uname -s`
if [ "$osname" = "AIX" ] || [ "$osname" = "OS400" ]; then
	ENC_UNICODE="UCS-2"
	ENC_CP437="IBM-437"
	ENC_CP1252="IBM-1252"
	ENC_CP932="IBM-932"
	ENC_LATIN1="ISO8859-1"
else
	# test on Linux and Solaris
	ENC_UNICODE="UCS-4LE"
	ENC_CP437="CP437"
	ENC_CP1252="CP1252"
	ENC_CP932="CP932"
	ENC_LATIN1="LATIN1"
fi

# function to write checking argument
checking_message()
{
	if [ "$osname" = "Linux" ]; then
		echo -n "Checking for $1..."
	else
		echo "Checking for $1...\c"
	fi	
}

# function to test the iconv command
execute_iconv()
{
	iconv_from=$1
	iconv_to=$2

	checking_message "iconv from $iconv_from to $iconv_to"
	$iconv -f $iconv_from -t $iconv_to $iconv_file > /dev/null 2> /dev/null
	if test $? -eq 2; then
		echo "FAILED"
	else
		echo "ok"
	fi
}

# create a simple file to test
iconv_file=/tmp/iconv_test.txt
echo "This is a test file for iconv" > $iconv_file

# find the iconv program
checking_message "iconv"
iconv=`which iconv`
if test -z $iconv; then
	echo "no\n"
	echo "ERROR: You need to install iconv command"
	exit 1
else
	echo "$iconv"
fi

# running tests to check the installed encodings 
# for PDF417
execute_iconv $ENC_CP1252  $ENC_CP437
execute_iconv $ENC_UNICODE $ENC_CP437

# for Data Matrix, Aztec Code, ...
execute_iconv $ENC_CP1252  $ENC_LATIN1
execute_iconv $ENC_UNICODE $ENC_LATIN1

# for QR-Code
execute_iconv $ENC_CP1252  $ENC_CP932
execute_iconv $ENC_UNICODE $ENC_CP932

